function [theta] = normalize(A, ns, theta)
%NORMALIZE Normalizes the CPTs of the Bayesian Network stacked in a vector
%  [theta] = NORMALIZE(A, ns, theta) normalizes the CPTS of the Bayesian
%     network stacked into a single vector.
%
%   The input and output parameters are as follows:
%    * A: adjacency matrix of the Bayesian network to use
%    * ns: vector of sizes of the nodes in network, i.e. number of discrete 
%       values the nodes can take
%    * theta: vector with CPTs to be normalized
%
%    * theta: normalized probabilities (i.e. they sum to one)
%
% --
% The provided software may be used free of charge for research purposes.
% For other uses and further support please contact Franz Pernkopf,
% pernkopf@tugraz.at.
%
% References:
%  F. Pernkopf, M. Wohlmayr, and S. Tschiatschek, 
%  "Maximum Margin Bayesian Network Classifiers," 
%  IEEE Transactions on Pattern Analysis and Machine Intelligence,
%  vol. 99, no. PrePrints, 2011
%
% Authors:
%  F. Pernkopf, M. Wohlmayr, and S. Tschiatschek
%
% Version:
%  1.0 August 24th, 2011
%

sidx = 1;
for n=1:length(ns),
    parents = logical(A(:,n));
    nrParentStates = prod(ns(parents));
    
    for i=1:nrParentStates,
        eidx = sidx + ns(n) - 1;
        theta(sidx:eidx) = theta(sidx:eidx) / sum(theta(sidx:eidx));
        
        sidx = sidx + ns(n);
    end
end

end

